/* Schema design: Oscar Koeroo - NIKHEF 2005 */

use jobrepository;


/* CE Specific */

CREATE TABLE jobs (
   job_id            int                  NOT NULL AUTO_INCREMENT,
   job_repository_id VARCHAR(80)          NOT NULL,
   user_id           INT                  NOT NULL,
   service_id        INT                  NOT NULL,
   submit_cert_id    INT                  NOT NULL,
   retrieve_cert_id  INT                  NULL,
   rsl               BLOB                 NULL,
   lrms_id           VARCHAR(255)         NULL,
   gridjob_id        VARCHAR(255)         NULL,
   jobtype           VARCHAR(255)         NULL,
   metric_info       BLOB                 NULL,
   
   PRIMARY KEY (job_id),
   INDEX (job_repository_id),
   INDEX (user_id),
   FOREIGN KEY (user_id) REFERENCES users (user_id)
           ON DELETE NO ACTION
           ON UPDATE CASCADE
)
TYPE=InnoDB;


CREATE TABLE unix_uids (
   unix_uid_id       INT                  NOT NULL AUTO_INCREMENT,
   uid               INT                  NOT NULL,
   uid_name          VARCHAR(255)         NULL,
   voms_attribute_id INT                  NULL,
   job_id            INT                  NOT NULL,
   user_id           INT                  NOT NULL,
   use_time          DATETIME             NOT NULL,
   
   PRIMARY KEY (unix_uid_id),
   INDEX (voms_attribute_id),
   FOREIGN KEY (voms_attribute_id) REFERENCES voms_attributes (voms_attribute_id)
           ON DELETE NO ACTION
           ON UPDATE NO ACTION,
   INDEX (job_id),
   FOREIGN KEY (job_id) REFERENCES jobs (job_id)
           ON DELETE NO ACTION
           ON UPDATE NO ACTION,
   INDEX (user_id),
   FOREIGN KEY (user_id) REFERENCES users (user_id)
           ON DELETE NO ACTION
           ON UPDATE CASCADE
)
TYPE=InnoDB;


CREATE TABLE unix_gids (
   unix_gid_id       INT                  NOT NULL AUTO_INCREMENT,
   gid               INT                  NOT NULL,
   gid_name          VARCHAR(255)         NULL,
   is_primary        INT                  NOT NULL,
   voms_attribute_id INT                  NULL,
   job_id            INT                  NOT NULL,
   user_id           INT                  NOT NULL,
   use_time          DATETIME             NOT NULL,

   PRIMARY KEY (unix_gid_id),
   UNIQUE (is_primary, job_id),
   INDEX (voms_attribute_id),
   FOREIGN KEY (voms_attribute_id) REFERENCES voms_attributes (voms_attribute_id)
           ON DELETE NO ACTION
           ON UPDATE NO ACTION,
   INDEX (job_id),
   FOREIGN KEY (job_id) REFERENCES jobs (job_id)
           ON DELETE NO ACTION
           ON UPDATE NO ACTION,
   INDEX (user_id),
   FOREIGN KEY (user_id) REFERENCES users (user_id)
           ON DELETE NO ACTION
           ON UPDATE CASCADE
)
TYPE=InnoDB;



CREATE TABLE jobstatus (
   job_repository_id  VARCHAR(64)           NOT NULL,
   status             VARCHAR(64)           NOT NULL,
   status_change      DATETIME              NOT NULL,

   PRIMARY KEY (job_repository_id, status, status_change),
   INDEX (job_repository_id),
   FOREIGN KEY (job_repository_id) REFERENCES jobs (job_repository_id)
           ON DELETE CASCADE
           ON UPDATE CASCADE
)
TYPE=InnoDB;


/*

  grant select                  on JobRepository.* to jobrep_script@'%.nikhef.nl' IDENTIFIED BY 'jobrep_script';
  grant insert                  on JobRepository.jobstatus to jobrep_script@'%.nikhef.nl' IDENTIFIED BY 'jobrep_script';
  grant select, insert, update  on JobRepository.* to lcmaps_jobrep@'%.nikhef.nl' IDENTIFIED BY 'jobrep_lcmaps';

*/
