/* Schema design: Oscar Koeroo - NIKHEF 2005 */


create database jobrepository;

use jobrepository;


/* Generic */

CREATE TABLE users (
   user_id         INT                   NOT NULL AUTO_INCREMENT,
   dn              VARCHAR(255)          NOT NULL,

   PRIMARY KEY (user_id),
   UNIQUE (dn)
)
TYPE=InnoDB;


CREATE TABLE user_certificates (
   cert_id         INT                   NOT NULL AUTO_INCREMENT,
   user_id         INT                   NOT NULL,
   subject         VARCHAR(255)          NOT NULL,
   valid_from      DATETIME              NOT NULL,
   valid_until     DATETIME              NOT NULL,
   cert            BLOB                  NOT NULL,
   parent_cert_id  INT                   NULL,
   first_use       DATETIME              NOT NULL,

   PRIMARY KEY (cert_id),
   INDEX (user_id),
   UNIQUE (subject, valid_from, valid_until),
   FOREIGN KEY (user_id) REFERENCES users (user_id) 
           ON DELETE NO ACTION
           ON UPDATE NO ACTION
)
TYPE=InnoDB;


CREATE TABLE action_types (
   action_type_id     INT              NOT NULL,
   action_type        VARCHAR(64)      NOT NULL,

   PRIMARY KEY (action_type_id),
   UNIQUE (action_type)
)
TYPE=InnoDB;


CREATE TABLE service_actions (
   service_action_id      INT            NOT NULL AUTO_INCREMENT,
   action_type_id         INT            NOT NULL,
   use_time               DATETIME       NOT NULL,
   user_id                INT            NOT NULL,
   cert_id                INT            NULL,
   
   PRIMARY KEY (service_action_id),
   INDEX (action_type_id),
   FOREIGN KEY (action_type_id) REFERENCES action_types (action_type_id)
           ON DELETE NO ACTION
           ON UPDATE NO ACTION,
   INDEX (use_time),
   INDEX (user_id),
   FOREIGN KEY (user_id) REFERENCES users (user_id)
           ON DELETE NO ACTION
           ON UPDATE NO ACTION
)
TYPE=InnoDB;


CREATE TABLE voms_fqans (
   fqan_id         INT                   NOT NULL AUTO_INCREMENT,
   fqan            VARCHAR(255)          NOT NULL,

   PRIMARY KEY (fqan_id)
)
TYPE=InnoDB;


CREATE TABLE voms_servers (
   server_id       INT                   NOT NULL AUTO_INCREMENT,
   server_dn       VARCHAR(255)          NOT NULL,
   server_ca       VARCHAR(255)          NULL,

   PRIMARY KEY (server_id)
)
TYPE=InnoDB;


CREATE TABLE voms_attributes (
   voms_attribute_id  INT                NOT NULL AUTO_INCREMENT,
   valid_from         DATETIME           NULL,
   valid_until        DATETIME           NULL,
   fqan_id            INT                NOT NULL,
   server_id          INT                NULL,         
/*   server_id          INT                NOT NULL,         */
   user_id            INT                NOT NULL,
   service_action_id     INT                NULL,

   PRIMARY KEY (voms_attribute_id),
   INDEX (fqan_id),
   FOREIGN KEY (fqan_id) REFERENCES voms_fqans (fqan_id)
           ON DELETE NO ACTION
           ON UPDATE CASCADE,
/* 
   INDEX (server_id),
   FOREIGN KEY (server_id) REFERENCES voms_servers (server_id)
           ON DELETE NO ACTION
           ON UPDATE CASCADE,
*/
   INDEX (user_id),
   FOREIGN KEY (user_id) REFERENCES users (user_id)
           ON DELETE NO ACTION
           ON UPDATE CASCADE
)
TYPE=InnoDB;



/* Initial value */

INSERT INTO action_types (action_type_id, action_type) values (1, 'LCMAPS');


/*

  grant select                  on JobRepository.* to jobrep_script@'%.nikhef.nl' IDENTIFIED BY 'jobrep_script';
  grant insert                  on JobRepository.jobstatus to jobrep_script@'%.nikhef.nl' IDENTIFIED BY 'jobrep_script';
  grant select, insert, update  on JobRepository.* to lcmaps_jobrep@'%.nikhef.nl' IDENTIFIED BY 'jobrep_lcmaps';

*/
